@@ -1,23 +1,19 @@
-# -*- coding: utf-8 -*-
 from zope.browser.interfaces import IAdding
 from zope.interface import Interface
 
 
 class IContentRulesInfo(Interface):
-    """Site-wide information about content rules
-    """
+    """Site-wide information about content rules"""
 
     def show_rules_tab():
-        """Determine whether or not the rules tab should be shown.
-        """
+        """Determine whether or not the rules tab should be shown."""
 
 
 class IContentRulesControlPanel(Interface):
-    """Marker interface for rules control panel view
-    """
+    """Marker interface for rules control panel view"""
 
     def globally_disabled():
-        """Wether content rules are globally disabled or not"""
+        """Whether content rules are globally disabled or not"""
 
 
 class IRuleAdding(IAdding):
@@ -43,5 +39,4 @@ class IRuleActionAdding(IRuleElementAdding):
 
 
 class IContentRulesForm(Interface):
-    """Marker interface for forms that need content rules layout
-    """
+    """Marker interface for forms that need content rules layout"""
