@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.app.contentrules.actions.delete import DeleteAction
 from plone.app.contentrules.rule import Rule
 from plone.app.contentrules.tests.base import ContentRulesTestCase
@@ -7,40 +6,36 @@ from plone.contentrules.rule.interfaces import IExecutable
 from plone.contentrules.rule.interfaces import IRuleAction
 from zope.component import getMultiAdapter
 from zope.component import getUtility
-from zope.interface.interfaces import IObjectEvent
 from zope.interface import implementer
-from plone.app.testing import login
-from plone.app.testing import TEST_USER_ID
-from plone.app.testing import TEST_USER_NAME
-from plone.app.testing import setRoles
+from zope.interface.interfaces import IObjectEvent
 
 
 @implementer(IObjectEvent)
-class DummyEvent(object):
-
+class DummyEvent:
     def __init__(self, object):
         self.object = object
 
 
 class TestDeleteAction(ContentRulesTestCase):
-
     def testRegistered(self):
-        element = getUtility(IRuleAction, name='plone.actions.Delete')
-        self.assertEqual('plone.actions.Delete', element.addview)
+        element = getUtility(IRuleAction, name="plone.actions.Delete")
+        self.assertEqual("plone.actions.Delete", element.addview)
         self.assertEqual(None, element.editview)
         self.assertEqual(None, element.for_)
         self.assertEqual(IObjectEvent, element.event)
 
     def testInvokeAddView(self):
-        element = getUtility(IRuleAction, name='plone.actions.Delete')
+        element = getUtility(IRuleAction, name="plone.actions.Delete")
         storage = getUtility(IRuleStorage)
-        storage[u'foo'] = Rule()
-        rule = self.portal.restrictedTraverse('++rule++foo')
+        storage["foo"] = Rule()
+        rule = self.portal.restrictedTraverse("++rule++foo")
 
         adding = getMultiAdapter(
-            (rule.__of__(self.portal), self.portal.REQUEST), name='+action')
+            (rule.__of__(self.portal), self.portal.REQUEST), name="+action"
+        )
         addview = getMultiAdapter(
-            (adding.__of__(rule), self.portal.REQUEST), name=element.addview)
+            (adding.__of__(rule), self.portal.REQUEST), name=element.addview
+        )
         addview()
 
         e = rule.actions[0]
@@ -49,8 +44,7 @@ class TestDeleteAction(ContentRulesTestCase):
     def testExecute(self):
         e = DeleteAction()
 
-        ex = getMultiAdapter(
-            (self.folder, e, DummyEvent(self.folder.d1)), IExecutable)
+        ex = getMultiAdapter((self.folder, e, DummyEvent(self.folder.d1)), IExecutable)
         self.assertEqual(True, ex())
 
-        self.assertFalse('d1' in self.folder.objectIds())
+        self.assertFalse("d1" in self.folder.objectIds())
