@@ -1,4 +1,3 @@
-from Acquisition import aq_base
 from email import message_from_bytes
 from plone.app.contentrules.actions.mail import MailAction
 from plone.app.contentrules.actions.mail import MailAddFormView
@@ -12,9 +11,7 @@ from plone.contentrules.engine.interfaces import IRuleStorage
 from plone.contentrules.rule.interfaces import IExecutable
 from plone.contentrules.rule.interfaces import IRuleAction
 from plone.registry.interfaces import IRegistry
-from Products.MailHost.interfaces import IMailHost
 from zope.component import getMultiAdapter
-from zope.component import getSiteManager
 from zope.component import getUtility
 from zope.interface import implementer
 from zope.interface.interfaces import IObjectEvent
